==> vtigercrm-5.2.1p2.tgz: modules/ProjectTask/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array(

	'LBL_MODULE_NAME'=>'Actividades',
  	'LBL_MODULE_TITLE'=>'Actividades',
	'LBL_NEW_PROJECTTASK'=>'Nueva Actividad',
    'LBL_PROJECTTASKS'=>'Actividades',
    'LBL_PROJECTTASK'=>'Actividades',
    'Project Task ID'=>'ID Actividad',
    'projectasks' => 'actividades',
    'ProjectTask'=>'Actividades',
    'SINGLE_ProjectTask' => 'Actividad',
	'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
    'LBL_PROJECT_TASK_INFORMATION' => 'Información Actividad',
    'LBL_DESCRIPTION_INFORMATION' => 'Descripción',
    'Assigned To' => 'Asignado a',
    //'linktoproject' => 'Link to Project',
    'Related Project' => 'Proyecto relacionado',
    'Priority' => 'Prioridad',
    'Progress' => 'Progreso',
    'Type'=>'Tipo',
    'Worked Hours'=>'Horas Trabajadas',
    'Start Date'=>'Fecha inicio',
    'End Date'=>'Fecha fin',
    'Related To' => 'Relacionado con',
    'projectid' => 'Proyecto',
   	'administrative' => 'administrativo',
    'operative' => 'operativo',
    'other' => 'otro',
    'low' => 'baja',
    'normal' => 'normal',
    'high' => 'alta',
    'Created Time' => 'Fecha Creación',
    'Modified Time' => 'Fecha Modificación',
    'Description' => 'Descripción',
    'description' => 'Descripción',
    //added for related lists
    'Project Task Name' => 'Nombre Actividad',
    'Project Task No' => 'Nº Actividad',
    'Project Task Number' => 'Código Actividad',
);

?>

==> vtigercrm-5.4.0.tgz: modules/ProjectTask/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * 
 * ***********************************************************
*  Module       : ProjectTask
*  Language     : ES Spanish
*  Version      : vt5.4.0
*  Created Date : 2012-02-27
*  Author       : JPL TSolucio, S.L.
*  License      : MPL 1.1
 ************************************************************************************/
$mod_strings = Array(

	'LBL_MODULE_NAME'=>'Actividades',
  	'LBL_MODULE_TITLE'=>'Actividades',
	'LBL_NEW_PROJECTTASK'=>'Nueva Actividad',
    'LBL_PROJECTTASKS'=>'Actividades',
    'LBL_PROJECTTASK'=>'Actividades',
    'Project Task ID'=>'ID Actividad',
    'projectasks' => 'actividades',
    'ProjectTask'=>'Actividades',
    'SINGLE_ProjectTask' => 'Actividad',
	'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
    'LBL_PROJECT_TASK_INFORMATION' => 'Información Actividad',
    'LBL_DESCRIPTION_INFORMATION' => 'Descripción',
    'Assigned To' => 'Asignado a',
    //'linktoproject' => 'Link to Project',
    'Related Project' => 'Proyecto relacionado',
    'Priority' => 'Prioridad',
    'Progress' => 'Progreso',
    'Type'=>'Tipo',
    'Worked Hours'=>'Horas Trabajadas',
    'Start Date'=>'Fecha inicio',
    'End Date'=>'Fecha fin',
    'Related To' => 'Relacionado con',
    'projectid' => 'Proyecto',
   	'administrative' => 'administrativo',
    'operative' => 'operativo',
    'other' => 'otro',
    'low' => 'baja',
    'normal' => 'normal',
    'high' => 'alta',
    'Created Time' => 'Fecha Creación',
    'Modified Time' => 'Fecha Modificación',
    'Description' => 'Descripción',
    'description' => 'Descripción',
    //added for related lists
    'Project Task Name' => 'Nombre Actividad',
    'Project Task No' => 'Nº Actividad',
    'Project Task Number' => 'Código Actividad',
	'ProjectTask ID'=>'Id Actividad',
);

?>
